==> xlniuxdata-pay-1.0.1-20160428.020436-3-sources.jar: com/xunlei/niux/data/pay/vo/AgentPayDetail.java <==
package com.xunlei.niux.data.pay.vo;


import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;



@Table(tableName="agentpaydetail",pkFieldName="seqId",pkFieldAssign=false)
public class AgentPayDetail {

	private Long seqId;
	private String agentId;
	private String gameId;
	private String serverid;
	private String userId;
	private String roleId;
	private String roleName;
	private String orderId;
	private String orderTime;
	private String orderIdStatus;
	private String ip;
	private String successTime;
	@Column(columnName="successTime",isWhereColumn=true,operator=Operator.GE)
	private String fromSuccessTime;
	@Column(columnName="successTime",isWhereColumn=true,operator=Operator.LT)
	private String toSuccessTime;
	private Double money;
	private Long gold;
	private String payCode;
	private String gameext;
	private String paramIp;
	private String paramTime;
	private String editBy;
	private String editTime;
	
	
	
	public String getFromSuccessTime() {
		return fromSuccessTime;
	}
	public void setFromSuccessTime(String fromSuccessTime) {
		this.fromSuccessTime = fromSuccessTime;
	}
	public String getToSuccessTime() {
		return toSuccessTime;
	}
	public void setToSuccessTime(String toSuccessTime) {
		this.toSuccessTime = toSuccessTime;
	}
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public String getAgentId() {
		return agentId;
	}
	public void setAgentId(String agentId) {
		this.agentId = agentId;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public String getServerid() {
		return serverid;
	}
	public void setServerid(String serverid) {
		this.serverid = serverid;
	}
	public String getUserId() {
		return userId;
	}
	public void setUserId(String userId) {
		this.userId = userId;
	}
	public String getRoleId() {
		return roleId;
	}
	public void setRoleId(String roleId) {
		this.roleId = roleId;
	}
	public String getRoleName() {
		return roleName;
	}
	public void setRoleName(String roleName) {
		this.roleName = roleName;
	}
	public String getOrderId() {
		return orderId;
	}
	public void setOrderId(String orderId) {
		this.orderId = orderId;
	}
	public String getOrderTime() {
		return orderTime;
	}
	public void setOrderTime(String orderTime) {
		this.orderTime = orderTime;
	}
	public String getOrderIdStatus() {
		return orderIdStatus;
	}
	public void setOrderIdStatus(String orderIdStatus) {
		this.orderIdStatus = orderIdStatus;
	}
	public String getIp() {
		return ip;
	}
	public void setIp(String ip) {
		this.ip = ip;
	}
	public String getSuccessTime() {
		return successTime;
	}
	public void setSuccessTime(String successTime) {
		this.successTime = successTime;
	}
	public Double getMoney() {
		return money;
	}
	public void setMoney(Double money) {
		this.money = money;
	}
	public Long getGold() {
		return gold;
	}
	public void setGold(Long gold) {
		this.gold = gold;
	}
	public String getPayCode() {
		return payCode;
	}
	public void setPayCode(String payCode) {
		this.payCode = payCode;
	}
	public String getGameext() {
		return gameext;
	}
	public void setGameext(String gameext) {
		this.gameext = gameext;
	}
	public String getParamIp() {
		return paramIp;
	}
	public void setParamIp(String paramIp) {
		this.paramIp = paramIp;
	}
	public String getParamTime() {
		return paramTime;
	}
	public void setParamTime(String paramTime) {
		this.paramTime = paramTime;
	}
	public String getEditBy() {
		return editBy;
	}
	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}
	public String getEditTime() {
		return editTime;
	}
	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}
	
	
	
}

==> xlniuxdata-pay-1.0.7-20170804.092908-2-sources.jar: com/xunlei/niux/data/pay/vo/AgentPayDetail.java <==
package com.xunlei.niux.data.pay.vo;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;

@Table(tableName = "agentpaydetail", pkFieldName = "seqId", pkFieldAssign = false)
public class AgentPayDetail {

	private Long seqId;
	private String agentId;
	private String gameId;
	private String serverid;
	private String userId;
	private String roleId;
	private String roleName;
	private String orderId;
	private String orderIdStatus;
	private String ip;
	
	private String successTime;
	@Column(columnName = "successTime", isWhereColumn = true, operator = Operator.GE)
	private String fromSuccessTime;
	@Column(columnName = "successTime", isWhereColumn = true, operator = Operator.LE)
	private String toSuccessTime;

	private String orderTime;
	@Column(columnName = "orderTime", isWhereColumn = true, operator = Operator.GE)
	private String fromOrderTime;
	@Column(columnName = "orderTime", isWhereColumn = true, operator = Operator.LE)
	private String toOrderTime;

	private Double money;
	private Long gold;
	private String payCode;
	private String gameext;
	private String paramIp;
	private String paramTime;
	private String editBy;
	private String editTime;

	public String getFromSuccessTime() {
		return fromSuccessTime;
	}

	public void setFromSuccessTime(String fromSuccessTime) {
		this.fromSuccessTime = fromSuccessTime;
	}

	public String getToSuccessTime() {
		return toSuccessTime;
	}

	public void setToSuccessTime(String toSuccessTime) {
		this.toSuccessTime = toSuccessTime;
	}

	public Long getSeqId() {
		return seqId;
	}

	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}

	public String getAgentId() {
		return agentId;
	}

	public void setAgentId(String agentId) {
		this.agentId = agentId;
	}

	public String getGameId() {
		return gameId;
	}

	public void setGameId(String gameId) {
		this.gameId = gameId;
	}

	public String getServerid() {
		return serverid;
	}

	public void setServerid(String serverid) {
		this.serverid = serverid;
	}

	public String getUserId() {
		return userId;
	}

	public void setUserId(String userId) {
		this.userId = userId;
	}

	public String getRoleId() {
		return roleId;
	}

	public void setRoleId(String roleId) {
		this.roleId = roleId;
	}

	public String getRoleName() {
		return roleName;
	}

	public void setRoleName(String roleName) {
		this.roleName = roleName;
	}

	public String getOrderId() {
		return orderId;
	}

	public void setOrderId(String orderId) {
		this.orderId = orderId;
	}

	public String getOrderTime() {
		return orderTime;
	}

	public void setOrderTime(String orderTime) {
		this.orderTime = orderTime;
	}

	public String getOrderIdStatus() {
		return orderIdStatus;
	}

	public void setOrderIdStatus(String orderIdStatus) {
		this.orderIdStatus = orderIdStatus;
	}

	public String getIp() {
		return ip;
	}

	public void setIp(String ip) {
		this.ip = ip;
	}

	public String getSuccessTime() {
		return successTime;
	}

	public void setSuccessTime(String successTime) {
		this.successTime = successTime;
	}

	public Double getMoney() {
		return money;
	}

	public void setMoney(Double money) {
		this.money = money;
	}

	public Long getGold() {
		return gold;
	}

	public void setGold(Long gold) {
		this.gold = gold;
	}

	public String getPayCode() {
		return payCode;
	}

	public void setPayCode(String payCode) {
		this.payCode = payCode;
	}

	public String getGameext() {
		return gameext;
	}

	public void setGameext(String gameext) {
		this.gameext = gameext;
	}

	public String getParamIp() {
		return paramIp;
	}

	public void setParamIp(String paramIp) {
		this.paramIp = paramIp;
	}

	public String getParamTime() {
		return paramTime;
	}

	public void setParamTime(String paramTime) {
		this.paramTime = paramTime;
	}

	public String getEditBy() {
		return editBy;
	}

	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}

	public String getEditTime() {
		return editTime;
	}

	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}

	public String getFromOrderTime() {
		return fromOrderTime;
	}

	public void setFromOrderTime(String fromOrderTime) {
		this.fromOrderTime = fromOrderTime;
	}

	public String getToOrderTime() {
		return toOrderTime;
	}

	public void setToOrderTime(String toOrderTime) {
		this.toOrderTime = toOrderTime;
	}

}
